package
Version:
v0.0.0-...-a42f9aa
Opens a new window with list of versions in this module.
Published: Oct 19, 2017
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package query defines methods for retrieving values from a data file.
Plan defines the most efficient lookups for retrieving an item from BoltDB.
Plan defines the most efficient lookups for retrieving an item from BoltDB.
func (b *Plan) UseIndex(name, key []byte)
type Query struct {
Item interface{}
Comparisons []*comparison
}
func (q *Query) First() interface{}
type UseIndex struct {
IndexBucket []byte
IndexKey []byte
}
Plan defines the most efficient lookups for retrieving an item from BoltDB.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.